pub struct NoContext;Trait Implementations
Sourceimpl ParseContext for NoContext
impl ParseContext for NoContext
Sourcefn show_context(&self, out: &mut String)
fn show_context(&self, out: &mut String)
Shows the error with the context in the original string.
original_input must be the original string on which this
error is based (so that position matches up).impl Copy for NoContext
impl StructuralPartialEq for NoContext