pub struct StringParseContext<B: Backing> {
pub position: usize,
pub backing: B,
}Expand description
A context for a parse error: the document (“backing”) and position in it. Unlike ParseableStr, owns the Backing, and does not contain the parsing window.
Fields
position: usizebacking: BTrait Implementations
Sourceimpl<'r, 's, B: Backing> From<&'r ParseableStr<'s, B>> for StringParseContext<&'s B>
impl<'r, 's, B: Backing> From<&'r ParseableStr<'s, B>> for StringParseContext<&'s B>
Sourcefn from(value: &'r ParseableStr<'s, B>) -> Self
fn from(value: &'r ParseableStr<'s, B>) -> Self
Converts to this type from the input type.
Sourceimpl<'s, B: Backing> From<ParseableStr<'s, B>> for StringParseContext<&'s B>
impl<'s, B: Backing> From<ParseableStr<'s, B>> for StringParseContext<&'s B>
Sourcefn from(value: ParseableStr<'s, B>) -> Self
fn from(value: ParseableStr<'s, B>) -> Self
Converts to this type from the input type.
Sourceimpl<'t, B: Backing> IntoOwningBacking<<B as ToOwned>::Owned> for StringParseContext<&'t B>
impl<'t, B: Backing> IntoOwningBacking<<B as ToOwned>::Owned> for StringParseContext<&'t B>
type Owning = StringParseContext<<B as ToOwned>::Owned>
fn into_owning_backing(self) -> Self::Owning
Sourceimpl<B: Backing> ParseContext for StringParseContext<B>
impl<B: Backing> ParseContext for StringParseContext<B>
Sourcefn show_context(&self, out: &mut String)
fn show_context(&self, out: &mut String)
Shows the error with the context in the original string.
original_input must be the original string on which this
error is based (so that position matches up).Sourceimpl<B: Backing> PartialEq for StringParseContext<B>
impl<B: Backing> PartialEq for StringParseContext<B>