pub struct ParseError<C: ParseContext> {
pub message: String,
pub context: C,
pub backtrace: Vec<FileLocation>,
}Fields
message: Stringcontext: Cbacktrace: Vec<FileLocation>Implementations
Sourceimpl<C: ParseContext> ParseError<C>
impl<C: ParseContext> ParseError<C>
pub fn to_string_showing_location(&self, show_backtrace: bool) -> String
Sourcepub fn show_backtrace(&self, out: &mut String)
pub fn show_backtrace(&self, out: &mut String)
‘Backtrace’ with the leaf location at the top, one location per line, indented by a tab, starting with a newline.
Sourcepub fn message_append(self, s: &str) -> Self
pub fn message_append(self, s: &str) -> Self
Append s to the message in self (functionally).