pub trait ParseContext: PartialEq {
// Required method
fn show_context(&self, out: &mut String);
}Required Methods
Sourcefn show_context(&self, out: &mut String)
fn show_context(&self, out: &mut String)
Shows the error with the context in the original string.
original_input must be the original string on which this
error is based (so that position matches up).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.